local log = Winning_Log
local L = LibStub("AceLocale-3.0"):GetLocale("Winning")
local addon = Winning
local ui_tabs = {'RECORDS', 'STATS'}



function Winning_Toggle_UI()
    if Winning_UI:IsVisible() then
        Winning_UI:Hide()
    else
        Winning_UI:Show();
    end
end



-- Used by the reporting buttons at the top of the UI
function Winning_Report(channel)
    log("Reporting to channel: " .. channel)

    local ctx = addon:current_context()
    local icon = "{skull}"

    local time_ctx = "(unknown)"
    if ctx.time.context == addon.dal.ALL then
        time_ctx = "ALL TIME"
    elseif ctx.time.context == addon.dal.SEASON then
        time_ctx = "THIS SEASON"
    elseif ctx.time.context == addon.dal.SIX_HOURS then
        time_ctx = "LAST SIX HOURS"
    end

    local type_ctx = L["All"]
    if ctx.type == addon.dal.CASUAL then
        type_ctx = L["Casual"]
    elseif ctx.type == addon.dal.RATED then
        type_ctx = L["Rated"]
    end

    local map_ctx = nil
    if ctx.map.value == 1 then
        map_ctx = "BGs"
    else
        map_ctx = tostring(addon.map_items[ctx.map.value])
    end

    local spec_ctx = ""
    if ctx.spec == 0 then
        
    else
        local id, spec_name, description, icon, background, role = GetSpecializationInfoByID(ctx.spec)
        spec_ctx = format(" (%s)", spec_name)
    end


    local wins, losses = addon.dal:win_loss()
    local win_loss_ratio = addon.dal:win_loss_ratio(wins, losses)
    SendChatMessage(format("%s %s %s%s: %s (%s:%s) -> WINNING %s", icon, type_ctx, map_ctx, spec_ctx, time_ctx, wins, losses, win_loss_ratio), channel, nil, nil)
end



-- Used to show contents of a single tab.
function Winning_Show_Tab(tab_name)
    if tab_name == ui_tabs[1] then
        Winning_UI_Stats:Hide()
        Winning_UI_Records:Show()
    elseif tab_name == ui_tabs[2] then
        Winning_UI_Records:Hide()
        Winning_UI_Stats:Show()
    end
end


-- Called when the tabs at the bottom of the UI are clicked.
function Winning_Tab_Clicked(tab_name)
    log("Tab clicked: " .. tab_name)
    for i, tab in ipairs(ui_tabs) do
        if tab == tab_name then
            PanelTemplates_SetTab(Winning_UI, i)
            Winning_Show_Tab(tab_name)
        end
    end
end


-- Called when the minimap button is clicked.
function Winning_Minimap_Click(btn)

    if btn == "LeftButton" or btn == nil then
        -- Manually calling this here because the items for this dropdown are
        -- generated based on battleground info, which isn't available right
        -- away when the addon is loading. Re-calling this function seems to
        -- re-create it and set the selected value correctly.
        --UIDropDownMenu_SetText(Winning_Map_DropDown, addon.map_items[addon.db.faction.map_context_value])

        log("Type dropdown value is: " .. tostring(addon.db.faction.type_context_value))
        log("Type dropdown text is: " .. addon.db.faction.type_context_value)
        UIDropDownMenu_SetSelectedValue(Winning_Type_DropDown, addon.db.faction.type_context_value)
        UIDropDownMenu_SetText(Winning_Type_DropDown, addon.db.faction.type_context_value)

        log("context dropdown value is: " .. tostring(addon.db.faction.time_context_value))
        log("context dropdown text is: " .. addon.db.faction.time_context_value)
        UIDropDownMenu_SetSelectedValue(Winning_Context_DropDown, addon.db.faction.time_context_value)
        UIDropDownMenu_SetText(Winning_Context_DropDown, addon.db.faction.time_context_value)

        log("map dropdown value is: " .. tostring(addon.db.faction.map_context_value))
        log("map dropdown text is: " .. addon.db.faction.map_context_value)
        UIDropDownMenu_SetSelectedValue(Winning_Map_DropDown, addon.db.faction.map_context_value)
        UIDropDownMenu_SetText(Winning_Map_DropDown, addon.map_items[addon.db.faction.map_context_value])

        log("spec dropdown value is: " .. tostring(addon.db.faction.map_context_value))
        log("spec dropdown text is: " .. addon.db.faction.map_context_value)
        UIDropDownMenu_SetSelectedValue(Winning_Spec_DropDown, addon.db.faction.spec_context_value)
        for i, v in pairs(addon.spec_items) do
            if v.spec == addon.db.faction.spec_context_value then
                UIDropDownMenu_SetText(Winning_Spec_DropDown, v.label)
            end
        end

        Winning_Toggle_UI()

    -- show and report premades 
    elseif 'btn' == 'RightButton' then
        -- TODO: Change to report player's faction
        premades.report(0)
	end
end



-- Handles setting up the type context dropdown.
function Winning_Type_DropDown_OnLoad(self, level)
    log("Type DropDown OnLoad")
    for i, v in pairs(addon.type_context_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = L[v]
        info.value = L[v]
        info.func = Winning_Type_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
    UIDropDownMenu_SetSelectedValue(Winning_Type_DropDown, addon.db.faction.type_context_value)
end

function Winning_Type_DropDown_OnClick(self)
    UIDropDownMenu_SetSelectedValue(Winning_Type_DropDown, self.value);
    if self.value then
        addon.db.faction.type_context_value = self.value
        log("Type context selected: " .. self.value)
        addon:context_updated()
    else
        log("No type context selected.")
    end
end


-- Handles setting up the time context dropdown.
function Winning_Context_DropDown_OnLoad(self, level)
    log("Context DropDown OnLoad")
    for i, v in pairs(addon.time_context_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = L[v]
        info.value = L[v]
        info.func = Winning_Context_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
    UIDropDownMenu_SetSelectedValue(Winning_Context_DropDown, addon.db.faction.time_context_value)
end

function Winning_Context_DropDown_OnClick(self)
    UIDropDownMenu_SetSelectedValue(Winning_Context_DropDown, self.value);
    if self.value then
        addon.db.faction.time_context_value = self.value
        log("Time context selected: " .. self.value)
        addon:context_updated()
    else
        log("No time context selected.")
    end
end



-- Handles setting up the maps dropdown.
function Winning_Map_DropDown_OnLoad(self, level)
    log("Map DropDown OnLoad")

    for i, v in pairs(addon.map_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = v
        info.value = i
        info.func = Winning_Map_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
    log("Map context value in OnLoad is:" .. tostring(addon.db.faction.map_context_value))
    UIDropDownMenu_SetSelectedValue(Winning_Map_DropDown, addon.db.faction.map_context_value)
end


function Winning_Map_DropDown_OnClick(self)
    log("Map DropDown OnClick")
    UIDropDownMenu_SetSelectedValue(Winning_Map_DropDown, self.value);
    if self.value then
        log("Map selected id is: " .. tostring(self.value))
        addon.db.faction.map_context_value = self.value

        local map_name = addon.map_items[self.value]
        log("Map context selected: " .. map_name)
        addon:context_updated()
    else
        log("No map context selected.")
    end
end



-- Handles setting up the spec dropdown.
function Winning_Spec_DropDown_OnLoad(self, level)
    log("Spec DropDown OnLoad")
    for i, v in pairs(addon.spec_items) do
        local info = UIDropDownMenu_CreateInfo()
        info.text = v.label
        info.value = v.spec
        info.func = Winning_Spec_DropDown_OnClick
        UIDropDownMenu_AddButton(info, level);
    end
    UIDropDownMenu_SetSelectedValue(Winning_Spec_DropDown, addon.db.faction.spec_context_value)
end


function Winning_Spec_DropDown_OnClick(self)
    UIDropDownMenu_SetSelectedValue(Winning_Spec_DropDown, self.value);
    if self.value then
        addon.db.faction.spec_context_value = self.value
        log("Spec context selected: " .. tostring(self.value))
        addon:context_updated()
    else
        log("No spec context selected.")
        -- Try to workaround the dropdown not having a value for some reason.
        addon.db.faction.spec_context_value = "All"
    end
end




function Winning_BG_Button_OnClick(btn)
    PlaySound("igMainMenuOptionCheckBoxOn")
    log("Setting clicked map to: " .. btn.map_name)
    addon.stats_selected_map_name = btn.map_name
    Winning_UI_Stats_Maps_Details:Show()
    addon:updateStatsTab(addon.stats_selected_map_name)
end


function Winning_Graph_Context_DropDown_OnLoad(self, level)
    -- for i, v in ipairs(addon.stats_context_items) do
    --     local info = UIDropDownMenu_CreateInfo()
    --     info.text = L[v]
    --     info.func = Winning_Graph_Context_DropDown_OnClick
    --     UIDropDownMenu_AddButton(info, level);
    -- end
    -- UIDropDownMenu_SetSelectedID(self, addon.db.faction.graph_context_value or 1)
end


function Winning_Graph_Context_DropDown_OnClick(self)
	-- UIDropDownMenu_SetSelectedID(Winning_Context_DropDown, self:GetID());
    -- local selectedId = Winning_Context_DropDown['selectedID']
    -- local ctx = addon.time_context_items[selectedId]
    -- addon.db.faction.graph_context_value = selectedId
    -- log("Graph context selected: " .. tostring(ctx))
end

function Winning_Report_Premades()
    Winning_Premades.report(0)
end
